<?php

/**
 * This file contains QUI\PriceTableBricks\Controls\PriceTable
 */

namespace QUI\PriceTableBricks\Controls;

use QUI;
use QUI\Control;

/**
 * Price table class
 *
 * @author  www.pcsg.de (Michael Danielczok)
 * @package quiqqer/pricetable-bricks
 */
class PriceTable extends Control
{
    /**
     * PriceTable constructor.
     *
     * @param array $params
     */
    public function __construct(array $params = [])
    {
        // default options
        $this->setAttributes([
            'class' => 'qui-pricetable',
            'nodeName' => 'section',
            'inherit-template-colors' => false,
            'entries' => [],
            'display' => 'default'
        ]);

        parent::__construct($params);
    }

    /**
     * @return string
     */
    public function getBody(): string
    {
        $Engine = QUI::getTemplateManager()->getEngine();
        $entries = $this->getAttribute('entries');

        if (is_string($entries)) {
            $entries = json_decode($entries, true);
        }

        foreach ($entries as $key => $value) {
            $entries[$key]['features'] = json_decode($value['features'], true);
        }

        switch ($this->getAttribute('display')) {
            case 'default':
            default:
                $css = dirname(__FILE__) . '/PriceTable.Default.css';
                $template = dirname(__FILE__) . '/PriceTable.Default.html';
                break;
        }

        $noInheritTemplateColors = '';
        if (!$this->getAttribute('inherit-template-colors')) {
            $noInheritTemplateColors = 'no-inherit-template-colors';
        }

        $Engine->assign([
            'this' => $this,
            'entries' => $entries,
            'noInheritTemplateColors' => $noInheritTemplateColors
        ]);

        $this->addCSSFile($css);

        return $Engine->fetch($template);
    }

    /**
     * @return QUI\Interfaces\Projects\Site
     * @throws QUI\Exception
     */
    protected function getSite(): QUI\Interfaces\Projects\Site
    {
        if ($this->getAttribute('Site')) {
            return $this->getAttribute('Site');
        }

        $Site = QUI::getRewrite()->getSite();

        $this->setAttribute('Site', $Site);

        return $Site;
    }
}
